import { Env } from './configSystem/base';
import { BasicDict } from './types';
export interface Logger {
    log: (level: string, line: string, data?: any) => Logger;
    child: (dict: BasicDict) => Logger;
}
export declare function hrtimeToMs([ms, ns]: [number, number]): number;
export declare function measurePromiseTime(promise: Promise<any>): Promise<BigInt>;
export declare const DummyLogger: Logger;
export declare enum LogLevel {
    error = 0,
    warn = 1,
    info = 2,
    http = 3,
    verbose = 4,
    debug = 5,
    silly = 6
}
export type LoggerTransportConfigCore = {
    enabled: boolean;
};
export type DataDogConfig = LoggerTransportConfigCore & {
    apiKey: string;
    source?: string;
    tags?: {
        [tag: string]: string;
    };
    intakeRegion?: string;
};
export type ConsoleConfig = LoggerTransportConfigCore & {
    json?: boolean;
};
export type LoggerTransportConfig = {
    datadog?: DataDogConfig;
    console?: ConsoleConfig;
};
export type LoggerInitArgs = {
    env: Env;
    name: string;
    transport?: {
        datadog?: DataDogConfig;
        console?: ConsoleConfig;
    };
};
export type LoggerInitOpts = LoggerInitArgs & {
    logLevel: LogLevel | string;
};
export declare const stringLogLevel: (level: LogLevel | string) => string;
export declare const logCall: <ARGS extends any[], RET>(logger: Logger, name: string, level: string | LogLevel, f: (...args: ARGS) => RET) => (...args: ARGS) => RET;
type Req = {
    method: string;
    originalUrl: string;
    body: BasicDict;
};
export declare const loggingMiddleware: (logger: Logger, aditionalData?: ((req: any) => string) | undefined) => (req: Req, _: any, next: Function) => void;
export declare const init: (argOpts: LoggerInitArgs) => Logger;
export {};
